@@ -5,7 +5,7 @@ use Getopt::Long;
 use VMware::vCloud;
 use strict;
 
-my $version = ( split ' ', '$Revision: 1.1 $' )[1];
+my $version = ( split ' ', '$Revision: 1.2 $' )[1];
 
 my ( $username, $password, $hostname);
 my $orgname = 'System';
@@ -16,8 +16,8 @@ my $ret = GetOptions ( 'username=s' => \$username, 'password=s' => \$password,
 die "Check the POD. This script needs command line parameters." unless
  $username and $password and $orgname and $hostname;
 
-my $vcd = new VMware::vCloud (
-  $hostname, $username, $password, $orgname
-);
+my $vcd = new VMware::vCloud ( $hostname, $username, $password, $orgname );
 
-my $login = $vcd->login;
\ No newline at end of file
+$vcd->config( debug => 1 ); # Turn debug text on.
+
+my $login = $vcd->login; # Login
\ No newline at end of file
